--- layout: base title: What's New navbar_active: whats-new relative_path: ../ --- {% capture jumbotron_h1 %} What's New{% endcapture %} {% capture jumbotron_p %}What's New in the latest version — Font Awesome {{ site.fontawesome.minor_version }}{% endcapture %} {% include jumbotron.html %} {% include stripe-social.html %}
{% include new-features.html %} {% include new-naming.html %} {% include new-upgrading.html %} {% include icons/new.html %}